AuthorizationDecision

Enum AuthorizationDecision 

pub enum AuthorizationDecision {
    Allowed,
    Denied(AuthorizationFailure),
    RequiresPolicy(AuthorizationName),
}
Authorization result that can defer one named policy to application code.

Variants



Allowed

Access is allowed.



Denied(AuthorizationFailure)

Access is denied for a safe stable reason.



RequiresPolicy(AuthorizationName)

A named policy evaluator must make the final decision.

Implementations

Source

impl AuthorizationDecision

pub fn enforce(self) -> SoapResult<()>

Converts a final decision into the stable soaprs error model.