pub struct SecretString(/* private fields */);Expand description
Opaque secret value whose debug and display representations are redacted.
Implementations
Sourceimpl SecretString
impl SecretString
Sourcepub fn new(value: impl Into<String>) -> SoapResult<Self>
pub fn new(value: impl Into<String>) -> SoapResult<Self>
Creates a non-empty secret.
Sourcepub fn expose_secret(&self) -> &str
pub fn expose_secret(&self) -> &str
Exposes the secret only at the authentication implementation boundary.